MemoryAccess

Enum MemoryAccess 

pub enum MemoryAccess {
    Direct {
        memory_block_symbols: usize,
    },
    Indirect {
        memory_block_symbols: usize,
    },
}
Controls how the channel accesses memory.

Variants



Direct

Enables the DMA backend for the channel. Using the DMA allows a significant amount of the channel’s workload to be offloaded from the CPU. However, the DMA backend is not available on all ESP chips, please refer to TRM before you enable this option. Or you might encounter a ESP_ERR_NOT_SUPPORTED error.

Fields

memory_block_symbols: usize

This field controls the size of the internal DMA buffer. To achieve a better throughput and smaller CPU overhead, you can set a larger value, e.g., 1024.



Indirect

Disables direct memory access. The CPU will have to read/write the data transferred from/to the RMT memory.

Fields

memory_block_symbols: usize

This field controls the size of the dedicated memory block owned by the channel, which should be at least 64.