ReceiveConfig

Struct ReceiveConfig 

pub struct ReceiveConfig {
    pub signal_range_min: Duration,
    pub signal_range_max: Duration,
    pub enable_partial_rx: bool,
    pub timeout: Option<TickType_t>,
    /* private fields */
}

Fields

signal_range_min: Duration

Specifies the minimal valid pulse duration in either high or low logic levels.

A pulse width that is smaller than this value is treated as a glitch, and ignored by the hardware.

signal_range_max: Duration

Specifies the maximum valid pulse duration in either high or low logic levels.

A pulse width that is bigger than this value is treated as Stop Signal, and the receiver generates receive-complete event immediately.

enable_partial_rx: bool

Set this flag if the incoming data is very long, and the driver can only receive the data piece by piece, because the user buffer is not sufficient to save all the data.

timeout: Option<TickType_t>

Maximum time to wait for data to be received.

If None, the driver will wait indefinitely.