pub struct TransmitConfig {
pub loop_count: Loop,
pub eot_level: bool,
pub queue_non_blocking: bool,
/* private fields */
}Fields
loop_count: LoopSpecify the times of transmission in a loop, -1 means transmitting in an infinite loop
eot_level: boolSet the output level for the “End Of Transmission”
queue_non_blocking: boolIf set, when the transaction queue is full, driver will not block the thread but return directly.